import {Component} from '@angular/core';
import {MatCheckbox} from "@angular/material/checkbox";
import {MatError, MatFormField, MatLabel} from "@angular/material/form-field";
import {MatInput} from "@angular/material/input";
import {MatTooltip} from "@angular/material/tooltip";
import {FormBuilder, FormGroup, ReactiveFormsModule, Validators} from "@angular/forms";
import {NavigationService} from "@service/navigation.service";
import SetupService from "@api/v1/setup.service";
import {of} from "rxjs";

@Component({
  selector: 'app-password-policy',
  standalone: true,
  imports: [
    MatCheckbox,
    MatFormField,
    MatInput,
    MatLabel,
    MatTooltip,
    ReactiveFormsModule,
    MatError
  ],
  templateUrl: './password-policy.component.html'
})
export class PasswordPolicyComponent {
  protected policyForm!: FormGroup;

  constructor(
    private navigationService: NavigationService, private formBuilder: FormBuilder, private api: SetupService) {
    this.policyForm = this.formBuilder.group({
      minimumLength: ['', [
        Validators.required,
        Validators.min(6),
        Validators.max(12)
      ]],
      requireLetter: [false],
      requireLettersDifferentCase: [false],
      requireDigit: [false],
      requireSpecialCharacter: [false]
    });

    this.api.passwordPolicyConfiguration().subscribe(response => {
      if (!response)
        return;

      this.navigationService.setSkipButtonState(true);
      this.navigationService.skipButtonAction = () => of(true);
      this.navigationService.triggerAutoSkip(this.navigationService.skipButtonAction);

      this.policyForm.patchValue({
        minimumLength: response.minimumLength,
        requireLetter: response.requireLetter,
        requireLettersDifferentCase: response.requireLettersDifferentCase,
        requireDigit: response.requireDigit,
        requireSpecialCharacter: response.requireSpecialCharacter
      });
    });

    this.navigationService.setNextButtonState(false);
    this.policyForm.valueChanges.subscribe(() => {
      this.navigationService.setNextButtonState(this.policyForm.valid);
    });

    this.navigationService.setSkipButtonState(true);
    this.navigationService.skipButtonAction = () => this.api.setPasswordPolicy(null);

    this.navigationService.nextButtonAction = () => {
      return this.api.setPasswordPolicy(({
        minimumLength: this.policyForm.get('minimumLength')?.value,
        requireLetter: this.policyForm.get('requireLetter')?.value,
        requireLettersDifferentCase: this.policyForm.get('requireLettersDifferentCase')?.value,
        requireDigit: this.policyForm.get('requireDigit')?.value,
        requireSpecialCharacter: this.policyForm.get('requireSpecialCharacter')?.value
      }));
    };
  };
}
